@@ -2,7 +2,7 @@
 remove_chunks <- function(path) {
   path <- normalizePath(path, mustWork = TRUE)
   filename <- basename(path)
-  lines <- readLines(path)
+  lines <- readLines(path, encoding = 'UTF-8')
 
   pattern <- get_knitr_pattern(filename, lines)
   if (is.null(pattern$chunk.begin) || is.null(pattern$chunk.end)) {
@@ -27,16 +27,12 @@ remove_chunks <- function(path) {
   return(lines)
 }
 
-file_ext <- function(...){
-  utils::getFromNamespace('file_ext', 'knitr')(...)
-}
-
 detect_pattern <- function(...){
   utils::getFromNamespace('detect_pattern', 'knitr')(...)
 }
 
 get_knitr_pattern <- function(filename, lines) {
-  pattern <- detect_pattern(lines, tolower(file_ext(filename)))
+  pattern <- detect_pattern(lines, tolower(tools::file_ext(filename)))
   if (!is.null(pattern)) {
     knitr::all_patterns[[pattern]]
   } else {
